#ifndef CLIB_UTILITY_PROTOS_H
#define CLIB_UTILITY_PROTOS_H

/*
**    $VER: utility_protos.h 53.21 (29.9.2013)
**
**    C prototypes. For use with 32 bit integers only.
**
**    Copyright (C) 1985-2005 Hyperion Entertainment VOF and Amiga, Inc.
**        All Rights Reserved
**
**    Copyright (c) 2010 Hyperion Entertainment CVBA.
**        All Rights Reserved.
*/

#ifndef   EXEC_PORTS_H
#include <exec/ports.h>
#endif
#ifndef   UTILITY_TAGITEM_H
#include <utility/tagitem.h>
#endif
#ifndef   UTILITY_DATE_H
#include <utility/date.h>
#endif
#ifndef   UTILITY_HOOKS_H
#include <utility/hooks.h>
#endif
#ifndef   UTILITY_NAME_H
#include <utility/name.h>
#endif
#ifndef   UTILITY_DATA_STRUCTURES_H
#include <utility/data_structures.h>
#endif
#ifndef   UTILITY_RANDOM_H
#include <utility/random.h>
#endif
#ifndef   UTILITY_MESSAGE_DIGEST_H
#include <utility/message_digest.h>
#endif

#ifdef __amigaos4__
#error Include <proto/> header files, not <clib/> header files in OS4.
#endif

#ifdef __cplusplus
#ifdef __USE_AMIGAOS_NAMESPACE__
namespace AmigaOS {
#endif
extern "C" {
#endif /* __cplusplus */

/*--- functions in V36 or higher (Release 2.0) ---*/

/* Tag item functions */

struct TagItem *FindTagItem( Tag tagVal, CONST struct TagItem *tagList );
ULONG GetTagData( Tag tagValue, ULONG defaultVal, CONST struct TagItem *tagList );
ULONG PackBoolTags( ULONG initialFlags, CONST struct TagItem *tagList, CONST struct TagItem *boolMap );
struct TagItem *NextTagItem( struct TagItem **tagListPtr );
VOID FilterTagChanges( struct TagItem *changeList, struct TagItem *originalList, ULONG apply );
VOID MapTags( struct TagItem *tagList, CONST struct TagItem *mapList, ULONG mapType );
struct TagItem *AllocateTagItems( ULONG numTags );
struct TagItem *CloneTagItems( CONST struct TagItem *tagList );
VOID FreeTagItems( struct TagItem *tagList );
VOID RefreshTagItemClones( struct TagItem *clone, CONST struct TagItem *original );
BOOL TagInArray( Tag tagValue, CONST Tag *tagArray );
ULONG FilterTagItems( struct TagItem *tagList, CONST Tag *filterArray, ULONG logic );

/* Hook functions */

ULONG CallHookPkt( struct Hook *hook, APTR object, APTR paramPacket );

/* Date functions */

VOID Amiga2Date( ULONG seconds, struct ClockData *result );
ULONG Date2Amiga( CONST struct ClockData *date );
ULONG CheckDate( CONST struct ClockData *date );

/* 32 bit integer muliply functions */

LONG SMult32( LONG arg1, LONG arg2 );
ULONG UMult32( ULONG arg1, ULONG arg2 );

/* 32 bit integer division funtions. The quotient and the remainder are */
/* returned respectively in d0 and d1 */

LONG SDivMod32( LONG dividend, LONG divisor );
ULONG UDivMod32( ULONG dividend, ULONG divisor );
/*--- functions in V37 or higher (Release 2.04) ---*/

/* International string routines */

LONG Stricmp( CONST_STRPTR string1, CONST_STRPTR string2 );
LONG Strnicmp( CONST_STRPTR string1, CONST_STRPTR string2, LONG length );
TEXT ToUpper( ULONG character );
TEXT ToLower( ULONG character );
/*--- functions in V39 or higher (Release 3) ---*/

/* More tag Item functions */

VOID ApplyTagChanges( struct TagItem *list, CONST struct TagItem *changeList );

/* 64 bit integer muliply functions. The results are 64 bit quantities */
/* returned in D0 and D1 */

LONG SMult64( LONG arg1, LONG arg2 );
ULONG UMult64( ULONG arg1, ULONG arg2 );

/* Structure to Tag and Tag to Structure support routines */

ULONG PackStructureTags( APTR pack, CONST ULONG *packTable, CONST struct TagItem *tagList );
ULONG UnpackStructureTags( CONST_APTR pack, CONST ULONG *packTable, struct TagItem *tagList );

/* Object-oriented NameSpaces */

BOOL AddNamedObject( struct NamedObject *nameSpace, struct NamedObject *object );
struct NamedObject *AllocNamedObjectA( CONST_STRPTR name, CONST struct TagItem *tagList );
struct NamedObject *AllocNamedObject( CONST_STRPTR name, Tag tag1, ... );
LONG AttemptRemNamedObject( struct NamedObject *object );
struct NamedObject *FindNamedObject( struct NamedObject *nameSpace, CONST_STRPTR name, struct NamedObject *lastObject );
VOID FreeNamedObject( struct NamedObject *object );
STRPTR NamedObjectName( struct NamedObject *object );
VOID ReleaseNamedObject( struct NamedObject *object );
VOID RemNamedObject( struct NamedObject *object, struct Message *message );

/* Unique ID generator */

ULONG GetUniqueID( VOID );


/*--- functions in V50 or higher (Beta release for developers only) ---*/

/* String manipulation and formatting */

LONG Strlcpy( STRPTR destination, CONST_STRPTR source, LONG size );
LONG Strlcat( STRPTR destination, CONST_STRPTR source, LONG size );
LONG VSNPrintf( STRPTR buffer, LONG buffer_size, CONST_STRPTR format, APTR args );
LONG SNPrintf( STRPTR buffer, LONG buffer_size, CONST_STRPTR format, ... );
STRPTR VASPrintf( CONST_STRPTR format, APTR args );
STRPTR ASPrintf( CONST_STRPTR format, ... );

/* Skip lists */

struct SkipList *CreateSkipList( struct Hook *hook, LONG max_levels );
VOID DeleteSkipList( struct SkipList *list );
struct SkipNode *InsertSkipNode( struct SkipList *list, APTR key, ULONG data_size );
struct SkipNode *FindSkipNode( CONST struct SkipList *list, APTR key );
LONG RemoveSkipNode( struct SkipList *list, APTR key );
struct SkipNode *GetFirstSkipNode( CONST struct SkipList *list );
struct SkipNode *GetNextSkipNode( CONST struct SkipList *list, CONST struct SkipNode *node );

/* Splay trees */

struct SplayTree *CreateSplayTree( struct Hook *hook );
VOID DeleteSplayTree( struct SplayTree *st );
struct SplayNode *InsertSplayNode( struct SplayTree *tree, APTR key, ULONG data_size );
struct SplayNode *FindSplayNode( CONST struct SplayTree *tree, APTR key );
LONG RemoveSplayNode( struct SplayTree *tree, APTR key );

/* Fill memory with a constant byte */

APTR SetMem( APTR destination, ULONG c, LONG length );

/* Find a list node by name (case-insensitive) */

struct Node *FindNameNC( struct List *list, CONST_STRPTR name );

/* Pseudo-random number generation */

LONG Random( struct RandomState *state );

/* Message digest calculation */

VOID MessageDigest_SHA_Init( struct MessageDigest_SHA *mdsha );
VOID MessageDigest_SHA_Update( struct MessageDigest_SHA *mdsha, APTR data, LONG num_bytes );
VOID MessageDigest_SHA_Final( struct MessageDigest_SHA *mdsha );


#ifdef __cplusplus
}
#ifdef __USE_AMIGAOS_NAMESPACE__
}
#endif
#endif /* __cplusplus */

#endif /* CLIB_UTILITY_PROTOS_H */
