#ifndef DOS_ANCHORPATH_H
#define DOS_ANCHORPATH_H
/*
**    $VER: anchorpath.h 53.21 (29.9.2013)
**
**    Pattern-matching structure definitions
**
**    Copyright (C) 1985-2009 Hyperion Entertainment VOF and Amiga, Inc.
**        All Rights Reserved
**
**    Copyright (c) 2010 Hyperion Entertainment CVBA.
**        All Rights Reserved.
**
*/
                      
#ifndef EXEC_LIBRARIES_H
#include <exec/libraries.h>
#endif

#ifndef EXEC_LISTS_H
#include <exec/lists.h>
#endif

#ifndef DOS_DOS_H
#include <dos/dos.h>
#endif

/****************************************************************************/

#ifdef __cplusplus
#ifdef __USE_AMIGAOS_NAMESPACE__
namespace AmigaOS {
#endif
extern "C" {
#endif

#ifdef __GNUC__
   #ifdef __PPC__
    #pragma pack(2)
   #endif
#elif defined(__VBCC__)
   #pragma amiga-align
#endif

/****************************************************************************/

/* Forward declaration for below */
struct AChain;

/****************************************************************************/


/****************************************************************************/
/* Returned by obsolete Examine(), ExamineFH() and ExNext(), it must also be
 * allocated on a 4 byte boundary address.
 *
 * This structure is obsolete, due to 4 gig file size limits, short string 
 * length issues and lack of extensibility.
 * Software should migrate to using the new ExamineDir() and the ExamineObject()
 * functions which use the struct ExamineData. 
 * 
 * This structure is here because it is nested within other structures and for
 * legacy compatibility reasons, so this definition can't be removed at this time.
 */

struct FileInfoBlock
{
    uint32           fib_DiskKey;       /* -- FILESYSTEM PRIVATE !!               */
    int32            fib_DirEntryType;  /* Use FIB_IS_ macros to identify object. */
    TEXT             fib_FileName[108]; /* Null terminated.                       */
    uint32           fib_Protection;    /* Bit mask of protection, rwxd are 3-0.  */

    int32            fib_Obsolete;      /* -- OBSOLETE !! - Do not access this.   */
                                        /* Change old source code to reference    */
                                        /* the fib_DirEntryType member instead.   */
                                        /* Handlers should init this to the same  */
                                        /* value as fib_DirEntryType.             */

    uint32           fib_Size;          /* Byte size of file, only good to 4 gig. */
    uint32           fib_NumBlocks;     /* Number of blocks in file               */
    struct DateStamp fib_Date;          /* Date file last changed                 */
    TEXT             fib_Comment[80];   /* Null terminated comment string.        */

    /* Note: the following fields are not supported by all filesystems.
       They should be initialized to 0 when sending an ACTION_EXAMINE packet.
       When Examine() is called, these are set to 0 for you.
       AllocDosObject() also initializes them to 0. */
    uint16           fib_OwnerUID;      /* owner's UID */
    uint16           fib_OwnerGID;      /* owner's GID */
    void *           fib_Reserved[8];
}; 
/* FileInfoBlock */






/*****************************************************************************/
/*  Obsolete definition ==ONLY== for legacy reference, pre V50.76 DOS.       */
/*  This is what DOS will expect when NOT allocated by AllocDosObject().     */
/*****************************************************************************/

struct AnchorPathOld
{
    struct AChain *      ap_Base;       /* pointer to first anchor */
    struct AChain *      ap_Last;       /* pointer to last anchor */
    int32                ap_BreakBits;  /* Bits we want to break on */
    int32                ap_FoundBreak; /* Bits we broke on. Also returns ERROR_BREAK */
    int8                 ap_Flags;      /* New use for extra word. */
    int8                 ap_Reserved;
    int16                ap_Strlen;     /* This is what ap_Length used to be */
    struct FileInfoBlock ap_Info;
    TEXT                 ap_Buf[1];     /* Buffer for path name, allocated by user */
};






/***********************************************************************
************************ PATTERN MATCHING ******************************
************************************************************************
*
* Structure expected by MatchFirst, MatchNext.
* Allocate this structure ONLY with AllocDosObject() from DOS 50.76+
* and initialize the ADO_Flags with the appropriate bits as follows:
*
* Set ADO_Mask, (ap_BreakBits) to the signal bitmask (^CDEF) that you want to
* take a break on, or 0L, (default) if you don't want to convenience the user.
*
* If you want to have the FULL PATH NAME of the files you found,
* allocate an additional buffer space using the tag ADO_Strlen, this will 
* place the buffer in ap_Buffer and the size into ap_Strlen.  
*
* If you don't want the full path name, DO NOT USE the ADO_Strlen tag, 
* this will set ap_Strlen to zero, with no additional buffer space.
* In this case, the name of the file, and stats are available in the 
* ap_Info, as per FileInfoBlock, or ExamineData ap_ExData pointer
* if the ap_ExData member is not NULL. 
* 
*
* Then call MatchFirst() and then afterwards, MatchNext() with this structure.
* You should check the return value each time (see below) and take the
* appropriate action, ultimately calling MatchEnd() when there are
* no more files and you are done.  You can tell when you are done by
* checking for the normal AmigaDOS return code ERROR_NO_MORE_ENTRIES.
*
*
******************************************************************************
* WARNING:  You MUST now allocate these with AllocDosObject() from DOS 50.76+ 
*           MatchXXX() will simply not work if you do not heed this warning.
******************************************************************************
*/

#ifndef USE_OLD_ANCHORPATH

struct AnchorPath                         /* redefined for dos 50.76+    */
{
    int32                ap_Magic;        /* DOS compatibility magic     */
    struct AChain *      ap_Base;         /* Pointer to first anchor     */
    struct AChain *      ap_Last;         /* Pointer to last anchor      */
    uint32               ap_BreakBits;    /* Bits we want to break on    */
    uint32               ap_FoundBreak;   /* Bits we broke on.           */
    uint32               ap_Flags;        /* The flags bitfield.         */
    struct ExamineData * ap_ExData;       /* Ptr to optional ExamineData */
    APTR                 ap_DosPrivate;   /* Internal DOS use only.      */
    uint32               ap_Reserved[2];  /* Future use, currently 0     */
    int32                ap_Strlen;       /* Length of the buffer        */
    STRPTR               ap_Buffer;       /* Full name, (see ADO_Strlen) */
    struct FileInfoBlock ap_Info;         /* The old FileInfoBlock space */
    uint32               ap_Private1;     /* --PRIVATE, internal use !!  */
    uint32               ap_Private2;     /* --PRIVATE, internal use !!  */
};


#else  /* USE_OLD_ANCHORPATH */

#define ap_Length     ap_Flags     /* Old compatability for LONGWORD ap_Length */
#define AnchorPath    AnchorPathOld  

#endif  /* USE_OLD_ANCHORPATH */



/****************************************************************************/
/* 
 * Some usefull synonyms.
 */

#define ap_First      ap_Base
#define ap_Current    ap_Last



/***************************************************************************/
/* 
 * Flags for AnchorPath->ap_Flags.
 */

#define APB_DOWILD       0  /* Unused */

#define APB_ITSWILD      1  /* Set by MatchFirst, used by MatchNext.
                               Application can test APB_ITSWILD, too
                              (means that there's a wildcard
                               in the pattern after calling
                               MatchFirst). */

#define APB_DODIR        2  /* Bit is SET if a DIR node should be
                               entered. Application can RESET this
                               bit after MatchFirst/MatchNext to AVOID
                               entering a dir. */

#define APB_DIDDIR       3  /* Bit is SET for an "expired" dir node. */

#define APB_NOMEMERR     4  /* Set on memory error */

#define APB_DODOT        5  /* Unused */

#define APB_DirChanged   6  /* ap_Current->an_Lock changed
                               since last MatchNext call */

#define APB_FollowHLinks 7  /* follow hardlinks on DODIR - defaults
                               to not following hardlinks on a DODIR. */

#define APB_MultiAssigns 8  /* Set this bit via AllocDosObject() to allow
                               Multi-Assign scanning to be enabled.  
                              ( NOTE: ONLY AVAILABLE FROM DOS 50.76+ ) */


#define APF_DOWILD       (1<<APB_DOWILD)
#define APF_ITSWILD      (1<<APB_ITSWILD)
#define APF_DODIR        (1<<APB_DODIR)
#define APF_DIDDIR       (1<<APB_DIDDIR)
#define APF_NOMEMERR     (1<<APB_NOMEMERR)
#define APF_DODOT        (1<<APB_DODOT)
#define APF_DirChanged   (1<<APB_DirChanged)
#define APF_FollowHLinks (1<<APB_FollowHLinks)

#define APF_MultiAssigns (1<<APB_MultiAssigns)    
                /* New for V50, See AllocDosObject() */



/****************************************************************************/
/* This flag is not available with old structures 8 bit flags field. */

#ifdef USE_OLD_ANCHORPATH
  #undef APB_MultiAssigns
  #undef APF_MultiAssigns
#endif

/****************************************************************************/



struct AChain
{
    struct AChain * an_Child;
    struct AChain * an_Parent;
    BPTR            an_Lock;
    struct FileInfoBlock
                    an_Info;
    uint8           an_Flags;
    TEXT            an_String[1];
};


/* Define for extending Matchxxx(). */
/* This structure is mainly for internal use. Compatibility via expediancy. */

#define an_ExData   ((struct ExamineData *)(an_Info.fib_Reserved[7]))



/*
 * Flags for AChain->an_Flags; almost all of these are private!
 */

#define DDB_PatternBit        0
#define DDB_ExaminedBit       1
#define DDB_Completed         2
#define DDB_AllBit            3
#define DDB_Single            4
#define DDB_Device            5 /* added V50  */

#define DDF_Device           (1<<DDB_Device)
#define DDF_Single           (1<<DDB_Single)
#define DDF_AllBit           (1<<DDB_AllBit)
#define DDF_Completed        (1<<DDB_Completed)
#define DDF_ExaminedBit      (1<<DDB_ExaminedBit)
#define DDF_PatternBit       (1<<DDB_PatternBit)

/* Values for AChain->an_Status, NOTE: These are the actual bit numbers */
#define COMPLEX_BIT    1     /* Parsing complex pattern */
#define EXAMINE_BIT    2     /* Searching directory */

/****************************************************************************/

#ifdef __GNUC__ 
   #ifdef __PPC__
    #pragma pack()
   #endif
#elif defined(__VBCC__)
   #pragma default-align
#endif


#ifdef __cplusplus
}
#ifdef __USE_AMIGAOS_NAMESPACE__
}
#endif
#endif

/****************************************************************************/

#endif /* DOS_ANCHORPATH_H */

